@@ -4,15 +4,14 @@ package WSDL::Compile::Utils;
 
 =head1 NAME
 
-WSDL::Compile::Utils - functions used by L<WSDL::Compile> and
-L<WSDL::Compile::Serialize> 
+WSDL::Compile::Utils - functions used by L<WSDL::Compile>.
 
 =cut
 
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our (@ISA, @EXPORT_OK);
 BEGIN {
@@ -137,10 +136,6 @@ sub parse_attr {
             $data{complexType}->{defined_in}->{types_xs} = 1;
         }
     } elsif (ref $tc eq 'Moose::Meta::TypeConstraint::Class') {
-        die "maxOccurs other then 1 for class is not supported - please use",
-            " ArrayRef[", $tc->name, "] in ", $attr->name,
-            " in ", $associated_class, "\n"
-                if $data{maxOccurs} ne '1';
         die $tc_orig->name, " is not supported - cannot have nillable complex types for ",
             $attr->name, " in ", $associated_class
             if $data{nillable};
